summaryrefslogtreecommitdiffstats
path: root/akregator/src/treenode.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/treenode.h')
-rw-r--r--akregator/src/treenode.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/akregator/src/treenode.h b/akregator/src/treenode.h
index 366677d39..d6c6f860e 100644
--- a/akregator/src/treenode.h
+++ b/akregator/src/treenode.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef AKREGATORTREENODE_H
@@ -48,9 +48,10 @@ class FetchQueue;
TODO: detailed description goes here
*/
-class TreeNode : public QObject
+class TreeNode : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -99,23 +100,23 @@ public:
virtual TreeNode* prevSibling() const;
- /** Returns the parent node.
- @return the parent feed group, 0 if there is none */
+ /** Returns the tqparent node.
+ @return the tqparent feed group, 0 if there is none */
- virtual Folder* parent() const;
+ virtual Folder* tqparent() const;
- /** Sets parent node; Don't call this directly, is done automatically by
+ /** Sets tqparent node; Don't call this directly, is done automatically by
insertChild-methods in @ref Folder. */
- virtual void setParent(Folder* parent);
+ virtual void setParent(Folder* tqparent);
/** Returns a sequence of the articles this node tqcontains. For feed groups, this returns a concatenated list of all articles in the sub tree.
If @c tag is not null, only articles tagged with @c tag are returned
@return sequence of articles */
- virtual TQValueList<Article> articles(const TQString& tag=TQString::null) = 0;
+ virtual TQValueList<Article> articles(const TQString& tag=TQString()) = 0;
/** returns a list of all tags occurring in this node (sub tree for folders) */
@@ -127,10 +128,10 @@ public:
virtual bool isGroup() const = 0;
/** exports node and child nodes to OPML (with akregator settings)
- @param parent the dom element the child node will be attached to
+ @param tqparent the dom element the child node will be attached to
@param document the opml document */
- virtual TQDomElement toOPML( TQDomElement parent, TQDomDocument document ) const = 0;
+ virtual TQDomElement toOPML( TQDomElement tqparent, TQDomDocument document ) const = 0;
/**
@param doNotify notification on changes on/off flag